@@ -288,7 +288,7 @@ class Distribution(object):
         setfig(fig)
         plt.plot(xs,self(xs),**kwargs)
         plt.xlabel(self.name)
-        plt.ylim(ymin=0)
+        plt.ylim(ymin=0,ymax=self(xs).max()*1.2)
 
     def resample(self,N,minval=None,maxval=None,log=False,res=1e4):
         """Returns random samples generated according to the distribution
@@ -486,6 +486,10 @@ class Hist_Distribution(Distribution):
         Keyword passed to `np.histogram`.  If integer, ths will be 
         the number of bins, if array-like, then this defines bin edges.
 
+    equibin : bool, optional
+        If true and ``bins`` is an integer ``N``, then the bins will be 
+        found by splitting the data into ``N`` equal-sized groups.
+
     smooth : int or float
         Smoothing parameter used by the interpolation function.
 
@@ -496,8 +500,16 @@ class Hist_Distribution(Distribution):
     kwargs
         Keyword arguments passed to `Distribution` constructor.
     """
-    def __init__(self,samples,bins=10,smooth=0,order=1,**kwargs):
+    def __init__(self,samples,bins=10,equibin=True,smooth=0,order=1,**kwargs):
         self.samples = samples
+        
+        if type(bins)==type(10) and equibin:
+            N = len(samples)//bins
+            sortsamples = np.sort(samples)
+            bins = sortsamples[0::N]
+            if bins[-1] != sortsamples[-1]:
+                bins = np.concatenate([bins,np.array([sortsamples[-1]])])
+
         hist,bins = np.histogram(samples,bins=bins,density=True)
         self.bins = bins
         bins = (bins[1:] + bins[:-1])/2.
@@ -972,6 +984,40 @@ class DoubleGauss_Distribution(Distribution):
         vals[lo] = lovals[lo]
         return vals
     
+def powerlawfn(alpha,minval,maxval):
+    C = powerlawnorm(alpha,minval,maxval)
+    def fn(inpx):
+        x = np.atleast_1d(inpx)
+        y = C*x**(alpha)
+        y[(x < minval) | (x > maxval)] = 0
+        return y
+    return fn
+
+def powerlawnorm(alpha,minval,maxval):
+    if np.size(alpha)==1:
+        if alpha == -1:
+            C = 1/np.log(maxval/minval)
+        else:
+            C = (1+alpha)/(maxval**(1+alpha)-minval**(1+alpha))
+    else:
+        C = np.zeros(np.size(alpha))
+        w = np.where(alpha==-1)
+        if len(w[0]>0):
+            C[w] = 1./np.log(maxval/minval)*np.ones(len(w[0]))
+            nw = np.where(alpha != -1)
+            C[nw] = (1+alpha[nw])/(maxval**(1+alpha[nw])-minval**(1+alpha[nw]))
+        else:
+            C = (1+alpha)/(maxval**(1+alpha)-minval**(1+alpha))
+    return C
+
+
+class PowerLaw_Distribution(Distribution):
+    def __init__(self,alpha,minval,maxval,**kwargs):
+        self.alpha = alpha
+        pdf = powerlawfn(alpha,minval,maxval)
+
+        Distribution.__init__(self,pdf,minval=minval,maxval=maxval)
+
 
 ######## KDE ###########
 
